@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Dict, List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple, Union
 
 from pydantic.main import BaseConfig
 
@@ -147,7 +147,7 @@ class Item(CamelModel):  # noqa: WPS110
 
     descr_text: Optional[str]
     flavour_text: Optional[List[str]]
-    flavour_text_parsed: Optional[List[FlavourTextParsed]]
+    flavour_text_parsed: Optional[List[Union[str, FlavourTextParsed]]]
     prophecy_text: Optional[str]
     is_relic: Optional[bool]
     replica: Optional[bool]
